==> otu-5000-18.54.tar: acterna/release/smartotu/app/services/security/SMTAccessControl.php <==
<?php
// *********************************************************
// NOTICE: All rights reserved. This material contains the
// trade secrets and confidential information of JDSU
// which embody substantial creative effort,
// ideas and expressions. No part of this material may be
// reproduced or transmitted in any form or by any means,
// electronic, mechanical, optical or otherwise, including
// photocopying and recording or in connection with any
// information storage or retrieval system, without
// specific written permission from JDSU
// Copyright JDSU 2012. All rights reserved.
// *********************************************************
namespace app\services\security;

use app\services\SMTIService;

use app\admin\SMTRoleDto;

use \Luracast\Restler\iAuthenticate;
use \app\http\SMTContext;
use app\admin\SMTUserUtil;
use app\util\SMTLogger;
use app\admin\SMTAuthenticationException;

/**
 * Authentication class
 * 
 * 
 * @author sdesplat
 */
class SMTAccessControl implements iAuthenticate
{
    /**
     * Required role names documented in api method:
     *   
     * 	* <@>access protected 
	 *  * <@>class SMTAccessControl {@requires user}
	 *  
     * They are injected by framework ( Util::setproperties ):
     * 
     * @var array
     */
	public $requires = null;	
	
	/**
	 * Control acces to a protected api method: the user must be allowed to access that method.
	 * If the user is not already logged in, try to log him, either check his role.
	 * When access control is required on a service method (all services accessed by the GWT client except the login/logout and OTU alarm, activity services ),
	 * the PHP session holding the current user is restored.
	 * 
	 * @see \Luracast\Restler\iFilter::__isAllowed()
	 */
	public function __isAllowed()
	{
	    $isAllowedToExecute = false;
	    $userIdentifiers = null;
	    $isApiRequest = self::isApiRequest();
	    
	    //SMTRestlerRouter injected by framework
	    $context = SMTContext::getContext( $this->restler );
	    
	    //Restore PHP session context: PHP session context must be restored to handle session time-out and user identifiers.
	    $session = $context->getSessionContext( self::isSessionTimeoutToCheck() );
	    
	    //try to login directly from http request header if the user is not already logged in
	    if ( ($session->getUser() == null) || ( $isApiRequest) ) //require login for each public API request
	    {
	        $userIdentifiers = $context->getHttpRequest()->decodeUserAuthorizationFromHeader();
	        if ( $userIdentifiers != null )
	        {
	            //test if user exists
	            $user = SMTUserUtil::authenticate($context, $userIdentifiers[0], "", base64_encode($userIdentifiers[1]) );	
	            $session->setUser($user);	    
	        }
	        else
	        {
	        	$session->setUser(NULL);
	        }
	    }    
	    
	    // test if one required role is a role of the current user 
	    // or if the OTU is connected in local mode and the user role is not read-only
	    if ( $session->getUser() != null ) 
	    {
	    	// check only Token against Cross-Site Request Forgery for web application, not for API (authorization from header) which doesn't use PHP session cookie
	    	if ( $isApiRequest || ( $context->getHttpRequest()->checkReferer() && $context->getHttpRequest()->checkToken( $this->restler->getTestRequestData() )) )
	    	{
		        if ( is_array( $this->requires  ) )
		        {
	    	        foreach ( $this->requires as $requiredRole )
	    	        {
	    	            if ( $session->getUser()->getRole()->isIncludingRole( $requiredRole ) || 
	    	                    ( $context->isLocalMode() && !$session->getUser()->getRole()->isEqual(SMTRoleDto::USER) ) ) 
	    	            {
	    	                $isAllowedToExecute = true;
	    	                break;
	    	            }
	    	        }
		        }
		        else
		        {
		            $isAllowedToExecute = $session->getUser()->getRole()->isIncludingRole( $this->requires ) || 
	    	                    ( $context->isLocalMode() && !$session->getUser()->getRole()->isEqual(SMTRoleDto::USER) );
		        }
	    	}
	    	else 
	    	{
	    		$isAllowedToExecute = FALSE;
	    		SMTLogger::getInstance()->trace( sprintf( "Invalid Token", SMTLogger::ERROR, __FILE__,__METHOD__,__LINE__));
	    	}
	    }
	    //if user is not authentified, return a user not authentified json error
	    else
	    {
        	$context->closeSession();
	    }
	    
	    return $isAllowedToExecute;
	}
	
	/**
	 * Basic access control for specific requests (conversations...) :
	 * only check that user is logged in and that referer has not changed
	 * 
	 * @return boolean
	 */
	public static function isAllowedBasicControl(SMTContext $context)
	{
		$isAllowedToExecute = false;
		$userIdentifiers = null;
				
		//Restore PHP session context: PHP session context must be restored to handle session time-out and user identifiers.
		$session = $context->getSessionContext( self::isSessionTimeoutToCheck() );
		
		// check if the user is already logged in
		if ( ($session->getUser() != null) && $context->getHttpRequest()->checkReferer() )
		{
			$isAllowedToExecute = true;
		}    
		else
		{
			//if user is not authentified, return a user not authentified json error
			$context->closeSession();
			throw new SMTAuthenticationException( SMTAuthenticationException::ERROR_BAD_LOGIN);
		}
		return $isAllowedToExecute;
	}
	
	/**
	 * Filter queries where session timeout musn't be checked.
	 * Don't check session timeout for message consumer registration/un-registration
	 * 
	 * @return boolean
	 */
	private static function isSessionTimeoutToCheck()
	{
	    return !( strpos( $_SERVER["REQUEST_URI"], "/".SMTIService::MESSAGE_SERVICE."/consumer" ) !== FALSE );
	}
	
	/**
	 * Filter queries coming from PUBLIC API.
	 *
	 * @return boolean
	 */
	private static function isApiRequest()
	{
		return ( (strpos( $_SERVER["REQUEST_URI"], "/api/" ) !== FALSE) || (strpos( $_SERVER["REQUEST_URI"], "/acquisitions/files" ) !== FALSE));
	}

}
?>

==> otu-5000-21.36.tar: acterna/release/smartotu/app/services/security/SMTAccessControl.php <==
<?php
// *********************************************************
// NOTICE: All rights reserved. This material contains the
// trade secrets and confidential information of JDSU
// which embody substantial creative effort,
// ideas and expressions. No part of this material may be
// reproduced or transmitted in any form or by any means,
// electronic, mechanical, optical or otherwise, including
// photocopying and recording or in connection with any
// information storage or retrieval system, without
// specific written permission from JDSU
// Copyright JDSU 2012. All rights reserved.
// *********************************************************
namespace app\services\security;

use app\services\SMTIService;

use app\admin\SMTRoleDto;

use \Luracast\Restler\iAuthenticate;
use \app\http\SMTContext;
use app\admin\SMTUserUtil;
use app\util\SMTLogger;
use app\admin\SMTAuthenticationException;

/**
 * Authentication class
 * 
 * 
 * @author sdesplat
 */
class SMTAccessControl implements iAuthenticate
{
    /**
     * Required role names documented in api method:
     *   
     * 	* <@>access protected 
	 *  * <@>class SMTAccessControl {@requires user}
	 *  
     * They are injected by framework ( Util::setproperties ):
     * 
     * @var array
     */
	public $requires = null;	
	
	/**
	 * Control acces to a protected api method: the user must be allowed to access that method.
	 * If the user is not already logged in, try to log him, either check his role.
	 * When access control is required on a service method (all services accessed by the GWT client except the login/logout and OTU alarm, activity services ),
	 * the PHP session holding the current user is restored.
	 * 
	 * @see \Luracast\Restler\iFilter::__isAllowed()
	 */
	public function __isAllowed()
	{
	    $isAllowedToExecute = false;
	    $userIdentifiers = null;
	    $isApiRequest = self::isApiRequest();
	    
	    //SMTRestlerRouter injected by framework
	    $context = SMTContext::getContext( $this->restler );
	    
	    //Restore PHP session context: PHP session context must be restored to handle session time-out and user identifiers.
	    $session = $context->getSessionContext( self::isSessionTimeoutToCheck() );
	    
	    //try to login directly from http request header if the user is not already logged in
	    if ( ($session->getUser() == null) || ( $isApiRequest) ) //require login for each public API request
	    {
	        $userIdentifiers = $context->getHttpRequest()->decodeUserAuthorizationFromHeader();
	        if ( $userIdentifiers != null )
	        {
	            //test if user exists
	            $user = SMTUserUtil::authenticate($context, $userIdentifiers[0], "", base64_encode($userIdentifiers[1]) );	
	            $session->setUser($user);	    
	        }
	        else
	        {
	        	$session->setUser(NULL);
	        }
	    }    
	    
	    // test if one required role is a role of the current user 
	    // or if the OTU is connected in local mode and the user role is not read-only
	    if ( $session->getUser() != null ) 
	    {
	    	// check only Token against Cross-Site Request Forgery for web application, not for API (authorization from header) which doesn't use PHP session cookie
	    	if ( !$isApiRequest )
	    	{
	    		$stream = $this->restler->getRequestStream();
	    		if ($stream != NULL)
	    		{
	    			$requestData = stream_get_contents($stream);
	    		}
	    	}
	    	
	    	if ( $isApiRequest || ( $context->getHttpRequest()->checkReferer() && $context->getHttpRequest()->checkToken( $requestData ) ) )
	    	{
		        if ( is_array( $this->requires  ) )
		        {
	    	        foreach ( $this->requires as $requiredRole )
	    	        {
	    	            if ( $session->getUser()->getRole()->isIncludingRole( $requiredRole ) || 
	    	                    ( $context->isLocalMode() && !$session->getUser()->getRole()->isEqual(SMTRoleDto::USER) ) ) 
	    	            {
	    	                $isAllowedToExecute = true;
	    	                break;
	    	            }
	    	        }
		        }
		        else
		        {
		            $isAllowedToExecute = $session->getUser()->getRole()->isIncludingRole( $this->requires ) || 
	    	                    ( $context->isLocalMode() && !$session->getUser()->getRole()->isEqual(SMTRoleDto::USER) );
		        }
	    	}
	    	else 
	    	{
	    		$isAllowedToExecute = FALSE;
	    		SMTLogger::getInstance()->trace( sprintf( "Invalid Token", SMTLogger::ERROR, __FILE__,__METHOD__,__LINE__));
	    	}
	    }
	    //if user is not authentified, return a user not authentified json error
	    else
	    {
        	$context->closeSession();
	    }
	    
	    return $isAllowedToExecute;
	}
	
	/**
	 * Basic access control for specific requests (conversations...) :
	 * only check that user is logged in and that referer has not changed
	 * 
	 * @return boolean
	 */
	public static function isAllowedBasicControl(SMTContext $context)
	{
		$isAllowedToExecute = false;
		$userIdentifiers = null;
				
		//Restore PHP session context: PHP session context must be restored to handle session time-out and user identifiers.
		$session = $context->getSessionContext( self::isSessionTimeoutToCheck() );
		
		// check if the user is already logged in
		if ( ($session->getUser() != null) && $context->getHttpRequest()->checkReferer() )
		{
			$isAllowedToExecute = true;
		}    
		else
		{
			//if user is not authentified, return a user not authentified json error
			$context->closeSession();
			throw new SMTAuthenticationException( SMTAuthenticationException::ERROR_BAD_LOGIN);
		}
		return $isAllowedToExecute;
	}
	
	public function __getWWWAuthenticateString()
	{
		return self::isApiRequest()? 'Basic realm=Access to the SmartOTU site' : 'Custom Token realm=Access to the SmartOTU site';
	}
	
	/**
	 * Filter queries where session timeout musn't be checked.
	 * Don't check session timeout for message consumer registration/un-registration
	 * 
	 * @return boolean
	 */
	private static function isSessionTimeoutToCheck()
	{
	    return !( strpos( $_SERVER["REQUEST_URI"], "/".SMTIService::MESSAGE_SERVICE."/consumer" ) !== FALSE );
	}
	
	/**
	 * Filter queries coming from PUBLIC API.
	 *
	 * @return boolean
	 */
	private static function isApiRequest()
	{
		return ( (strpos( $_SERVER["REQUEST_URI"], "/api/" ) !== FALSE ) || (strpos( $_SERVER["REQUEST_URI"], "/acquisitions/files" ) !== FALSE ) );
	}

}
?>
